@@ -1,5 +1,4 @@
 from enum import Enum
-from iso639 import languages
 
 
 class Fieldname(Enum):
@@ -23,9 +22,6 @@ class Fieldname(Enum):
     SUPPLEMENTAL = 'supp'
     LINKS = 'link'
 
-    # Special
-    BLANK = 'blank'
-
 
     @classmethod
     def link_friendly_fields(cls) -> set:
@@ -50,7 +46,4 @@ class Language(Enum):
     JAPANESE = 'jpn'
     ENGLISH = 'eng'
     HEBREW = 'heb'
-    ESPERANTO = 'epo'
-
-    def to_language_object(self):
-        return languages.get(part3=self.value)
+    ESPERANTO = 'epo'
\ No newline at end of file
