@@ -5,7 +5,7 @@ from cardbuilder.lookup.en_to_ja.ejdict_hand import EJDictHand
 from cardbuilder.lookup.en_to_ja.gene_dict import GeneDict
 from cardbuilder.lookup.eo_to_en.espdic import ESPDIC
 from cardbuilder.lookup.ja_to_en.jisho import Jisho
-from cardbuilder.lookup.ja_to_ja.nhk_pitch_accent import NhkPitchAccent
+from cardbuilder.lookup.ja.nhk_pitch_accent import NhkPitchAccent
 from cardbuilder.lookup.tatoeba import TatoebaExampleSentences
 
 instantiable_data_sources = {
