@@ -1,3 +1,4 @@
+import sqlite3
 from abc import ABC, abstractmethod
 from collections import OrderedDict
 from os import mkdir
@@ -6,9 +7,9 @@ from typing import Optional, Callable, get_type_hints, Dict
 
 import requests
 
-from cardbuilder.common.util import dedup_by, retry_with_logging
+from cardbuilder.common.util import dedup_by, retry_with_logging, InDataDir, DATABASE_NAME
 from cardbuilder.exceptions import CardBuilderUsageException
-from cardbuilder.lookup.value import SingleValue, ListValue, MultiListValue, MultiValue, Value
+from cardbuilder.lookup.value import SingleValue, ListValue, MultiListValue, MultiValue, Value, PitchAccentValue
 
 
 class Printer(ABC):
@@ -43,6 +44,40 @@ class SingleValuePrinter(Printer):
         return self.format_string.format(value=value.get_data())
 
 
+class PitchAccentPrinter(SingleValuePrinter):
+    """The printer for pitch accent values."""
+
+    def __init__(self, html: bool = False):
+        self.html = html
+
+    def __call__(self, value: PitchAccentValue) -> str:
+        pitch_accent_string = value.get_data()
+        word = value.word
+        prev_tone = None
+        if self.html:
+            output = ''
+            for pitch, word_char, idx in zip(pitch_accent_string, word, range(len(word))):
+                tone_class = pitch.lower()
+                if tone_class == PitchAccentValue.PitchAccent.DROP.value:
+                    if idx == len(word) - 1:  # final drop requires special CSS
+                        if prev_tone == PitchAccentValue.PitchAccent.HIGH.value:
+                            output += f'<span class="tone-drop-final">{word_char}</span>'
+                        else:
+                            output += f'<span class="tone-drop-final-change">{word_char}</span>'
+                        return output
+                    else:
+                        # otherwise it's just a normal high (presumably low comes next)
+                        tone_class = PitchAccentValue.PitchAccent.HIGH.value
+
+                if prev_tone is not None and prev_tone != tone_class:
+                    tone_class += '-change'
+                output += f'<span class="tone-{tone_class}">{word_char}</span>'
+                prev_tone = pitch.lower()
+            return output
+        else:
+            return f'{word}\n{pitch_accent_string}'
+
+
 class MultiValuePrinter(Printer):
     def __init__(self, value_printer: SingleValuePrinter = SingleValuePrinter(),
                  header_printer: Optional[SingleValuePrinter] = SingleValuePrinter('{value}: '), join_string: str = ', ',
@@ -111,7 +146,7 @@ class MultiListValuePrinter(Printer):
             for data_list, header in data:
                 if header not in grouped_data:
                     grouped_data[header] = list()
-                grouped_data[header].extend(x.get_data() for x in data_list.get_data())
+                grouped_data[header].extend(x for x in data_list.get_data())
 
             data = list((ListValue(val), key) for key, val in grouped_data.items())
 
@@ -137,8 +172,8 @@ class TatoebaPrinter(MultiValuePrinter):
         super(TatoebaPrinter, self).__init__(**kwargs)
 
     def __call__(self, value: MultiValue) -> str:
-        deduped_value = MultiValue([(x.get_data(), y.get_data()) for x, y in
-                                   dedup_by(dedup_by(value.get_data(), lambda x: x[0]), lambda x: x[1])])
+        deduped_value = MultiValue([(x, y) for x, y in
+                                    dedup_by(dedup_by(value.get_data(), lambda x: x[0]), lambda x: x[1])])
         return super().__call__(deduped_value)
 
 
@@ -146,6 +181,7 @@ class DefaultPrinter(Printer):
     def __call__(self, value: Value):
         return {
             SingleValue: SingleValuePrinter(),
+            PitchAccentValue: PitchAccentPrinter(),
             MultiValue: MultiValuePrinter(),
             ListValue: ListValuePrinter(),
             MultiListValue: MultiListValuePrinter()
@@ -180,6 +216,13 @@ class DownloadPrinter(Printer):
     def __init__(self, output_directory: str, format_string='{directory}/{filename}'):
         self.output_directory = output_directory
         self.format_string = format_string
+        with InDataDir():
+            self.conn = sqlite3.connect(DATABASE_NAME)
+
+        self.conn.execute('''CREATE TABLE IF NOT EXISTS download_cache (
+            url TEXT PRIMARY KEY,
+            content BLOB);''')
+        self.conn.commit()
 
     def __call__(self, value: Value) -> str:
         if isinstance(value, SingleValue):
@@ -196,8 +239,25 @@ class DownloadPrinter(Printer):
         if not exists(self.output_directory):
             mkdir(self.output_directory)
 
-        r = retry_with_logging(requests.get, tries=2, delay=1, fargs=[url])
+        data = self._get_cached_data(url)
+        if data is None:
+            r = retry_with_logging(requests.get, tries=2, delay=1, fargs=[url])
+            data = r.content
+            self._cache_data(url, data)
+
         with open(join(self.output_directory, filename), 'wb') as f:
-            f.write(r.content)
+            f.write(data)
 
         return self.format_string.format(directory=self.output_directory, filename=filename)
+
+    def _get_cached_data(self, url: str) -> Optional[bytes]:
+        cursor = self.conn.execute('SELECT content FROM download_cache WHERE url=?', (url,))
+        result = cursor.fetchone()
+        return result[0] if result else None
+
+    def _cache_data(self, url: str, data: bytes):
+        self.conn.execute('INSERT OR REPLACE INTO download_cache VALUES (?, ?)', (url, data))
+        self.conn.commit()
+
+
+
